#!/bin/bash -x
trap "shutdown -h now" ERR

yum -y install curl
yum -y update
yum -y upgrade

rpm -i CollabNetSubversion-client-1.5.6-1.i386.rpm

# Install EC2 API tools
wget http://s3.amazonaws.com/ec2-downloads/ec2-api-tools-1.3-30349.zip
unzip ec2-api-tools-1.3-30349.zip
mv ec2-api-tools-1.3-30349 /usr/local/ec2/ec2-api-tools


# JDK
wget -O construct.sh "https://jdk-distros.dev.java.net/source/browse/*checkout*/jdk-distros/trunk/utils/construct.sh?content-type=text%2Fplain&rev=148" --no-check-certificate

for JDK_VERSION in "5.0u17" "5.0u22" "6u11" "6u21";
do
    JDK_FILE="jdk-${JDK_VERSION}-dlj-linux-i586.bin"
    UNBUNDLE_DIR="unbundle-jdk-${JDK_VERSION}"

    wget "http://download.java.net/dlj/binaries/${JDK_FILE}"
    mkdir $UNBUNDLE_DIR
    cd $UNBUNDLE_DIR
    sh ../$JDK_FILE --accept-license
    cd ..
    sh construct.sh $UNBUNDLE_DIR /opt/jdk-$JDK_VERSION /opt/jre-$JDK_VERSION
    rm -rf $JDK_FILE $UNBUNDLE_DIR
done

# link newest JDKs as defaults
ln -s jdk-5.0u22 /opt/jdk-5
ln -s jdk-5/jre /opt/jre-5
ln -s jdk-6u21 /opt/jdk-6
ln -s jdk-6/jre /opt/jre-6

rm -f construct.sh



# Maven 2
curl --silent "http://archive.apache.org/dist/maven/binaries/apache-maven-2.0.11-bin.tar.bz2" | tar xjC /opt -f -
ln -fs /opt/apache-maven-2.0.11 /opt/maven-2.0

# Maven 2.1
curl --silent "http://archive.apache.org/dist/maven/binaries/apache-maven-2.1.0-bin.tar.bz2" | tar xjC /opt -f -
ln -fs /opt/apache-maven-2.1.0 /opt/maven-2.1

# Maven 2.2
curl --silent "http://archive.apache.org/dist/maven/binaries/apache-maven-2.2.1-bin.tar.bz2" | tar xjC /opt -f -
ln -fs /opt/apache-maven-2.2.1 /opt/maven-2.2

# Maven 1.1
curl --silent "http://archive.apache.org/dist/maven/binaries/maven-1.1.tar.bz2" | tar xjC /opt -f -

# Maven 1.0.2 (with patched optional Ant jar to allow forkmode once)
tar xzC /opt -f maven-1.0.2.tar.gz

# Ant
# curl --silent "http://archive.apache.org/dist/ant/binaries/apache-ant-1.7.1-bin.tar.bz2" | tar xjC /opt -f - 
# curl --silent "http://archive.apache.org/dist/ant/binaries/apache-ant-1.8.1-bin.tar.bz2" | tar xjC /opt -f - 
wget "http://archive.apache.org/dist/ant/binaries/apache-ant-1.7.1-bin.tar.bz2"
tar xjC /opt -f apache-ant-1.7.1-bin.tar.bz2

#Grails
wget "http://dist.codehaus.org/grails/grails-1.3.1.zip"
unzip grails-1.3.1.zip

wget "http://dist.codehaus.org/grails/grails-1.2.2.zip"
unzip grails-1.2.2.zip

# Mercurial 1.4 (from FC10)
wget --output-document /tmp/4EBFC273.txt https://fedoraproject.org/static/4EBFC273.txt
rpm --import /tmp/4EBFC273.txt
rm -f /tmp/4EBFC273.txt

wget --output-document /tmp/0B86274E.txt https://fedoraproject.org/static/0B86274E.txt
rpm --import /tmp/0B86274E.txt
rm -f /tmp/0B86274E.txt

rpm -ivh ftp://ftp.pbone.net/mirror/archive.fedoraproject.org/fedora/linux/updates/testing/10/i386/mercurial-1.4-1.fc10.i386.rpm

# Bamboo
useradd bamboo
tar xzC /opt -f bamboo-elastic-agent-$2.tar.gz
ln -s bamboo-elastic-agent-$2 /opt/bamboo-elastic-agent

# Default Maven repository TODO This will most likely be removed.
# tar xzC /home/bamboo -f maven1-repo.tar.gz
# chown -R bamboo:bamboo /home/bamboo/.maven

# tar xvzC /home/bamboo -f mvn-repository.tar.gz
# chown -R bamboo:bamboo /home/bamboo/.m2

# Custom capabilities
mv bamboo-capabilities.properties /home/bamboo/

# Correct permissions
chown -R bamboo:bamboo /home/bamboo/

# Environment
mv profile.sh /etc/profile.d/bamboo.sh
cat rc.local >> /etc/rc.d/rc.local

echo $3 >> motd
mv motd /etc/motd

# Remove logs
find /var/log -type f -exec rm "{}" \;

# Remove history files
rm -f /root/.viminfo /root/.lesshst /root/.bash_history

# Remove host ssh keys
rm –rf /etc/ssh/ssh_host_*key*
rm -f /root/firstlogin /root/.ssh/authorized_keys

# Set firstrun flag on Amazon images
touch /root/firstrun

# Bundle it
ec2-bundle-vol -c cert.pem -k pk.pem -u $4 -p elasticbamboo-$3 --batch --debug
ec2-upload-bundle -b $5 -m /tmp/elasticbamboo-$3.manifest.xml -a $6 -s $1 --retry --debug

shutdown -h now
